==> ace_6.0.1.orig.tar.gz: ACE_wrappers/TAO/tests/Param_Test/recursive_struct.h <==
// $Id: recursive_struct.h 76591 2007-01-25 18:17:52Z elliott_c $

// ============================================================================
//
// = LIBRARY
//    TAO/tests/Param_Test
//
// = FILENAME
//    recursive_struct.h
//
// = DESCRIPTION
//    Tests a structure that contains a sequence of itself
//
// = AUTHORS
//    Aniruddha Gokhale, Jeff Parsons
//
// ============================================================================

#ifndef PARAM_TEST_RECURSIVE_STRUCT_H
#define PARAM_TEST_RECURSIVE_STRUCT_H

#include "param_testC.h"
#include "helper.h"

// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*
//           test recursive structs
// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*

class Test_Recursive_Struct
{
public:
  Test_Recursive_Struct (void);
  // ctor

  ~Test_Recursive_Struct (void);
  // dtor

  int run_sii_test (Param_Test_ptr objref);
  // run the SII test

  const char *opname (void) const;
  // return operation name

  int init_parameters (Param_Test_ptr objref);
  // set values for parameters

  int reset_parameters (void);
  // reset values for CORBA

  CORBA::Boolean check_validity (void);
  // check if results are valid

  CORBA::Boolean check_validity (CORBA::Request_ptr req);
  // check if results are valid. This is used for DII results

  void print_values (void);
  // print all the values

  void dii_req_invoke (CORBA::Request *);
  // invoke DII request with appropriate exception handling.

private:
  char *opname_;
  // operation name

  Param_Test::Recursive_Struct in_;
  // in parameter

  // these need memory management
  Param_Test::Recursive_Struct_var inout_;
  // inout parameter

  Param_Test::Recursive_Struct_var out_;
  // out parameter

  Param_Test::Recursive_Struct_var ret_;
  // return value

  void deep_init (Param_Test::Recursive_Struct &rs,
                  Generator *gen,
                  CORBA::ULong level);
  // helper function for init_parameters

  CORBA::Boolean deep_check (const Param_Test::Recursive_Struct &in_struct,
                             const Param_Test::Recursive_Struct &test_struct);
  // helper function for check_validity
};

#endif /* PARAM_TEST_RECURSIVE_STRUCT_H */

==> ace_6.5.4.orig.tar.gz: ACE_wrappers/TAO/tests/Param_Test/recursive_struct.h <==

//=============================================================================
/**
 *  @file    recursive_struct.h
 *
 *  Tests a structure that contains a sequence of itself
 *
 *  @author Aniruddha Gokhale
 *  @author Jeff Parsons
 */
//=============================================================================


#ifndef PARAM_TEST_RECURSIVE_STRUCT_H
#define PARAM_TEST_RECURSIVE_STRUCT_H

#include "param_testC.h"
#include "helper.h"

// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*
//           test recursive structs
// =*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*=*

class Test_Recursive_Struct
{
public:
  /// ctor
  Test_Recursive_Struct (void);

  /// dtor
  ~Test_Recursive_Struct (void);

  /// run the SII test
  int run_sii_test (Param_Test_ptr objref);

  /// return operation name
  const char *opname (void) const;

  /// set values for parameters
  int init_parameters (Param_Test_ptr objref);

  /// reset values for CORBA
  int reset_parameters (void);

  /// check if results are valid
  CORBA::Boolean check_validity (void);

  /// check if results are valid. This is used for DII results
  CORBA::Boolean check_validity (CORBA::Request_ptr req);

  /// print all the values
  void print_values (void);

  /// invoke DII request with appropriate exception handling.
  void dii_req_invoke (CORBA::Request *);

private:
  /// operation name
  char *opname_;

  /// in parameter
  Param_Test::Recursive_Struct in_;

  // these need memory management
  /// inout parameter
  Param_Test::Recursive_Struct_var inout_;

  /// out parameter
  Param_Test::Recursive_Struct_var out_;

  /// return value
  Param_Test::Recursive_Struct_var ret_;

  /// helper function for init_parameters
  void deep_init (Param_Test::Recursive_Struct &rs,
                  Generator *gen,
                  CORBA::ULong level);

  /// helper function for check_validity
  CORBA::Boolean deep_check (const Param_Test::Recursive_Struct &in_struct,
                             const Param_Test::Recursive_Struct &test_struct);
};

#endif /* PARAM_TEST_RECURSIVE_STRUCT_H */
